package de.intevation.mxd.reader;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.PictureMarkerSymbol;
import com.esri.arcgis.carto.PictureElement;

import org.w3c.dom.Element;

/**
 * Reads picture marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class PictureMarkerSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(PictureMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private PictureMarkerSymbol symbol;

    public PictureMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof PictureMarkerSymbol) {
            this.symbol = (PictureMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a PictureMarkerSymbol!");
        }
    }

    public PictureMarkerSymbolReader(IMarkerSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof PictureMarkerSymbol) {
            this.symbol = (PictureMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a PictureMarkerSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        //TODO Read the picture from mxd and write it as base64 string to the
        //     XML Element.
        logger.debug("read()");
        Element symbolElement = util.addSymbol(parent);

        symbolElement.setAttribute(
            "angle",
            String.valueOf(symbol.getAngle()));
        symbolElement.setAttribute(
            "size",
            String.valueOf(symbol.getSize()));
        symbolElement.setAttribute(
            "x_offset",
            String.valueOf(symbol.getXOffset()));
        symbolElement.setAttribute(
            "y_offset",
            String.valueOf(symbol.getYOffset()));
        symbolElement.setAttribute(
            "name",
            symbol.getNameString());
        PictureElement pElem = new PictureElement();
        pElem.importPicture(symbol.getPicture());
        symbolElement.setAttribute("style", "picture");
        symbolElement.setAttribute("type", "marker");
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
